# django-islands

Oficial fork of [django-multitenant](https://github.com/citusdata/django-multitenant/) under development and maintenance.

## Warning

I haven't had much time to develop this project lately, but you can be sure that it is still under development! If you have any questions, suggestions for improvements or functionality or want to report a bug, feel free to contact me and I will try to fix the problem within 7 days.
